@@ -6,15 +6,22 @@ __all__ = [
     'text_input_tamil',
     'url_input',
     'url_input_classify',
+    'api_imagecaption_request',
+    'api_imagecaption_response',
     'api_ner_request',
     'api_ner_request_1',
     'api_ner_response',
     'api_qa_request',
     'api_qa_request_1',
     'api_qa_response',
+    'api_question_request',
+    'api_question_response',
     'api_summary_request',
     'api_summary_request_1',
     'api_summary_response',
+    'api_tableqa_request',
+    'api_tableqa_request_1',
+    'api_tableqa_response',
     'api_translate_request',
     'api_translate_request_1',
     'api_translate_response',
@@ -32,6 +39,10 @@ __all__ = [
     'input_10',
     'input_11',
     'input_12',
+    'input_13',
+    'input_14',
+    'input_15',
+    'input_16',
     'orignal_string',
     'responselemma',
     'responsepo',
